@@ -513,6 +513,10 @@ Prometheus.Graph.prototype.submitQuery = function() {
           return;
         }
 
+        if ("warnings" in json && json.warnings.length > 0) {
+          self.showWarning(json.warnings.join('<br>'));
+        }
+
         queryHistory.handleHistory(self);
         success(json.data, textStatus);
       },
@@ -734,13 +738,9 @@ Prometheus.Graph.prototype.updateGraph = function() {
         }
       });
     });
-    if (min === max) {
-      self.rickshawGraph.max = max + 1;
-      self.rickshawGraph.min = min - 1;
-    } else {
-      self.rickshawGraph.max = max + (0.1*(Math.abs(max - min)));
-      self.rickshawGraph.min = min - (0.1*(Math.abs(max - min)));
-    }
+    var offset = 0.1 * (min === max ? max : Math.abs(max-min));
+    self.rickshawGraph.max = max + offset;
+    self.rickshawGraph.min = min - offset;
   }
 
   var xAxis = new Rickshaw.Graph.Axis.Time({ graph: self.rickshawGraph });
